bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Der Nibelunge Nôt ## 9. Aventiure
___________________________________________________ #### Aventivre wie sivrit ze wormez #### in botschefte fvor
###### 529 | ### Do si gevarn waren | wol niwen tage ### do sprach von tronege hagene | nv hoert waz ich iv sage ### wir svmen vns mit den maeren | ce wormz an den rin ### iwer boten solden | nv ce bvrgvnden sin
###### 530 | ### do sprach der kvnich gvnther | ir habet mir war geseit ### vns waere ce der selben verte | niemen so bereit ### als ir min frivnt her hagene | nv ritet in min lant ### di mine hovereise | tvt in niemen baz bechant
###### 531 | ### des antwurte hagene | ich pin niht bote gvt ### lat mich pflegen der chamere | beliben vf der flvt ### ia wil ich bi den vrowen | behivten ir gewant ### vnz wir si bringen | in der bvrgende lant
###### 532 | ### nv pitet sifride | fveren di poteshapft ### der chan si wol gewerben | mit ellenthaffter crapft ### versage er iv di reise | ir svlt mit gvten siten ### dvrch iwer swester willen | der bete in vrivntlichen piten
###### 533 | ### er sande nach dem reken | der chom do man in vant ### er sprach sit wir heim nahen | in miniv lant ### so sold ich poten senden | der lieben swester min ### vnt miner mvter | daz wir nahen an den rin
###### 534 | ### des ger ich an ivch sifrit | nv leistet minen mvt ### daz ich ez iemer diene | sprach der degen gvt ### do widerredete iz sifrit | der vil chvne man ### vnz daz in gvnther | sere vlegen began
###### 535 | ### er sprach ir svlt riten | durch den willen min ### vnt ovch dvrch crimhilde | daz shone magedin ### daz ez mit mir verdiene | div herlichiv meit ### do daz gehorte sifrit | do was der recke vil bereit
###### 536 | ### nv enbietet swaz ir wellet | des wirt niht verdaget ### ich wil iz gerne werben | dvrch di vil shonen meit ### ziwiv sold ich verzihen | di ich in hercen han ### swaz ir gebietet | daz ist alliz getan
###### 537 | ### so saget miner mvter | vten der chvnegin ### daz wir an dirre verte | in hohen mvte sin ### lat wizzen mine brvder | wi wir geworben han ### ir svlt ovch vnser frivnde | disiv maere horen lan
###### 538 | ### di minen schonen swester | di svlt ir niht verdagen ### den min vnt prvnnhilde dienest | den svlt ir der maegde sagen ### vnt ovch dem gesinde | vnt allen minen man ### darnach ie ranch min herce | wi wol ich daz verendet han
###### 539 | ### vnt sagt oertwine | dem liebem naeven min ### daz er heizze sidelen | ce wormez an den rin ### vnt ander mine mage | sol man wizzen lan ### ich wil mit prvnnhilde | groze hohzite han
###### 540 | ### vnt sage miner swester | so si daz habe vernomen ### daz ich mit miner swester | si ce lande chomen ### daz si mit vlize enpfahe | di lieben trivtinne min ### daz wil ich immer diende | vmb crhimhilde sin
###### 541 | ### sifrit der herre | balde vrlovp genam ### von vrovn prvnnhilde | als im wol gezam ### virz allem ir gesinde | do reit aer an den rin ### ez chvnde in dirre werlde | ein bot bezzer niht gesin
###### 542 | ### mit vier vnt zweinzech recken | ce wormez er do reit ### des chvneges chom er ane | do daz wart geseit ### allez daz gesinde | mvte iamers not ### si vorhten daz ir herre | dort beliben waere tot
###### 543 | ### do rbeizten si von rossen | vil hohe stvnt ir mvt ### vil schiere chom in giselher | der ivnge chvnech gvt ### vnde gernot sin brvder | wi bald er do sprach ### do er den chvnich gvnther | niht bi sifride sach
###### 544 | ### sit willechomen sifrit | ir svlt mich wizen lan ### wa ir minen brvder | den kvnich habt verlan ### div prvnnhilde sterche | in wen vns hat benomen ### so waere ir hohiv minne | vns ce grozem shaden chomen
###### 545 | ### di angest lat beliben | iv vnt den magen sin ### iv enbivtet sinen dienest | der liebe hergeselle min ### den liez ich wol gesvnden | er hat mich iv gesant ### daz ich sin bote waere | mit maeren her in iwer lant
###### 546 | ### ir svlt daz ahten shiere | swi so daz geshaehe ### daz ich di kvneginne | von iwer swester saehe ### di sol ich lazen hoeren | waz in enboten hat ### gvnther vnt prvennhilt | ir dinch in hohe stat
###### 547 | ### do sprach der ivnge giselher | da svlt ir zv zir gan ### da habt ir miner swester | vil liebe angetan ### si treit ovch michel sorge | vmb den prvoder min ### div magt siht ivch gerne | des wil ich iwer bvrge sin
###### 548 | ### do sprach der herre sifrit | swaz ich ir dienen chan ### daz sol vil willechlichen | mit triwen sin getan ### wer saget nv den vrowen | daz ich dar wil gan ### des wart do bote giselher | der vil waetliche man
###### 549 | ### giselher der snelle | zv siner mvter sprach ### vnt ovch ce siner swester | da er si beide sach ### vns ist chomen sifrit | der helt vz niderlant ### in hat min brvder gvnther | her ce rine gesant
###### 550 | ### er bringet vns div maere | wi ez vmb den kvnich ste ### nv svlt ir im erlovben | daz er ce hove ge ### er sagt div rehten maere | her von islant ### noch was den edelen vrowen | michel sorge bechant
###### 551 | ### si sprvngen nach ir waete | do leiten si sich an ### si baten sifride | hin ce hove gan ### daz tet er willechlichen | want er si gerne sach ### crhimhilt div edele | zv im gvetlichen sprach
###### 552 | ### sit willechom her sifrit | ritter lobelich ### wa ist min brvder gvnther | der edel kvnich rich ### von prvnnhilde chrepfte | ich waen wir in han verlorn ### owe mich armer maegde | daz ich ce der werlt ie wart geborn
###### 553 | ### do sprah der ritter chvene | nv gebt mit botenprot ### ir vil schone vrowen | ir waeinet ane not ### ich liez in wol gesvnden | daz tvn ich iv bechant ### si habent mich iv beide | mit den maeren her gesant
###### 554 | ### iv enbivtet holden dienest | er vnt div wine sin ### mit vrivntlicher liebe | vil edeliv chvenegin ### nv lazet iwer weinen | si wellent shiere chomen ### si het in manigen citen | so liebez maere niht vernomen
###### 555 | ### mit snewizzen geren | ir ovgen wolgetan ### wishete si nach trehin | danchen si began ### dem boten dirre maere | div ir waren chomen ### do was ir michel trvren | vnt ir weinen benomen
###### 556 | ### si bat den boten sitzen | des was er vil bereit ### do sprach div minnechliche | mir waere niht ce leit ### ob ich dem boten miete | solde gebin min golt ### darzv sit ir ce riche | ich wil iv immer wesin holt
###### 557 | ### op ich nv eine hete | sprach er drizech lant ### so enpfienge ich doh gerne | gab vz iwerr hant ### do sprach div tvgentriche | nv sol ez sin getan ### si hiez den chamaeraer | nach der botenmiete gan
###### 558 | ### vier vnt zweinzech povge | mit gesteine gvt ### di gap si im ce miete | so stvnt des heldes mvt ### er woldes niht behalden | er gab iz sa cehant ### ir naehestim ingesinde | di er ce kemnaten vant
###### 559 | ### ir mvter bot ir dienest | in vil gvotlichen an ### ich sol iv sagen maere | sprach der chvne man ### wes ivch bitet gvnther | so er chvmt an den rin ### ob ir daz vrowe leistet | er well iv immer waege sin
###### 560 | ### di sinen richen geste | des hort ich in gern ### daz ir di wol enpfahet | vnd svlt in des gewern ### daz ir gegin im ritet | fver wormez an den sant ### des sit ir von dem chvenege | mit rehten triwen gemant
###### 561 | ### do sprach div minnechliche | des bin ich vil bereit ### swaz ich im chan gedienen | daz ist im vnverseit ### mit vrivntlichen triwen | so sol ez sin getan ### do merte sich ir varwe | di si vor liebe gewan
###### 562 | ### ez en wart nie bote enpfangen | deheines fvrsten baz ### getorste si in chvessen | div vrowe taete daz ### wi rehte minnechlich | er von den vrowen shiet ### do taten bvrgende | als in sifrit geriet
###### 563 | ### sindolt vnt hvnolt | vnt rvnolt der degen ### vil grozer vmmvze | mvsen do pflegen ### rihten daz gesidele | vor wormez vf den sant ### des chvniges shapfere | man mit arbeiten vant
###### 564 | ### ortwin vnt gere | di ne wolden daz niht lan ### si sanden nach den frivnden | allenthalben dan ### si chvndeten in di hohzit | div da solde sin ### da cierten sich engegene | div vil shonen magdin
###### 565 | ### der palas vnt di wende | daz was vberal ### gecieret gegen den gesten | der gvntheres sal ### der wart vil wol becimert | dvrch manegen vremden man ### disiv vil starche hohzit | div hvp sich vil vrolichen an
###### 566 | ### do ritten allenthalben | di waege dvrch daz lant ### der drier chvnege mage | di hete man besant ### daz si den solden warten | di in da wolden chomen ### da wart vzer valde | vil richer waete genomen
###### 567 | ### do sagete man div maere | daz man riten sach ### di prvnnhilde vrivnde | do hovp sich vngemach ### von des volches crepfte | in bvrgenden lant ### hey waz man chvener daegene | da ce beiden siten vant
###### 568 | ### do sprach div shone crimhilt | ir miniv magedin ### di an dem antpfange | mit mir wellen sin ### di svchen vz den chisten | div allerbesten chleit ### so wirt vns von den gesten | lob vnt ere geseit
###### 569 | ### do chomen ovch di rechen | di hiezen tragen dar ### di herlichen saetele | von rotem golde gar ### di vrowen solden riten | ce wormez an den rin ### bezzer pferhtgereite | div chvnden niender sin
###### 570 | ### hey waz da lihtes goldes | von den moeren shein ### in lvhte von den zovmen | vil manich edelstein ### di gvldinen shaemel | ob liehem pfelle gvt ### di braht man den vrowen | si waren vrolich gemvt
###### 571 | ### vffe dem hove waren | div vrowenpferht bereit ### den edeln ivnchvrowen | als ich iv han geseit ### div smalen fvrbvge | sach man di moeren tragen ### von den besten siden | da von iv iemen chvnde gesagen
###### 572 | ### sehs vnt ahzec vrowen | sach man da fver gan ### di gebende trvogen | zv crimhilde dan ### chomen di vil schone | vnt trvgen lihtiv kleit ### da chom ovch gecieret | maich waetlichiv meit
###### 573 | ### fvmpfcech vnt viere | von bvergvnde lant ### ez waren ovch di hohsten | di man da inder vant ### di sach man da valvahse | vnder liehten porten gan ### des e der chvnich gerte | daz wart mit vlize getan
###### 574 | ### si trvgen richen pfellel | di besten di man vant ### vor den vremden recken | so manich gvt gewant ### daz ir genvege shone | ce rehte wol gezam ### er waere in swachem mvte | der ir deheiner waere gram
###### 575 | ### von zobel vnt von harme | vil man da chleider vant ### da wart vil wol gecieret | manich arm vnt hant ### mit povgen ob den siden | di si da solden tragen ### iv en chvnde diz vlizen | ce ende niemen gesagen
###### 576 | ### vil manigen gvertel | spaehen rich vnt lanch ### vber liehtiv chleider | vil manich hant do swanch ### vf edel roche ferrans | von pfelle vz arabi ### den aedelen ivnchfrowen | was vil hoher frevden bi
###### 577 | ### ez wart in fvorgespenge | manich shoniv meit ### genaet vil minnechliche | ez moeht ir wesin leit ### der ir vil liehtiv varwe | niht lvhte gegen der wat ### so shones ingesindes | nv niht chvnges chvnne hat
###### 578 | ### do di vil minnechlichen | nv trvgen ir gewant ### di si da fvoren solden | di chomen dar cehant ### der hochmveten recken | was ein vil michel crapft ### man trvch ovch dar mit shilden | vil manich esshinen schapft

<<< Übersicht <<< vorige Seite nächste Seite >>>